@@ -1,5 +1,5 @@
 package App::Git::Info;
-$App::Git::Info::VERSION = '0.4.1';
+$App::Git::Info::VERSION = '0.6.0';
 # ABSTRACT: Displays a summary of information about the git repository.
 
 use strict;
@@ -17,20 +17,12 @@ __END__
 
 =head1 NAME
 
-App::Git::Info - Displays a summary of information about the git repository.
-
 =head1 VERSION
 
-version 0.4.1
+version 0.6.0
 
 =head1 SYNOPSIS
 
-=head1 NAME
-
-=head1 VERSION
-
-version 0.4.1
-
     shlomif@telaviv1:~/conf/trunk$ git info info
     ⇒ On branch master
      M shlomif-settings/home-bin-executables/bin/git-i
@@ -45,7 +37,7 @@ version 0.4.1
 
 Implement the info subcommand.
 
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
@@ -66,14 +58,6 @@ L<https://metacpan.org/release/App-Git-Info>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/App-Git-Info>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -82,22 +66,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-Git-Info>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/App-Git-Info>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/App-Git-Info>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
